@@ -2,7 +2,14 @@
 import numpy as np
 
 
-def qpoint(force_constant=[], qpt=[0.1, 0.1, 0.1]):
+def read_fc(filename="FORCE_CONSTANTS"):
+    """Read force-constants."""
+    from jarvis.io.phonopy.outputs import read_fc
+    fc = read_fc(filename)
+    return fc
+
+
+def qpoint(force_constant=[], qpt=[0.0, 0.0, 0.0]):
     """Get FC as natons x natons x 3 x3."""
     qpt = np.array(qpt)
     exp_iqpt = np.exp(1.0j * qpt)
